Coverage for C:\src\imod-python\imod\visualize\__init__.py: 100%

1"""

2 Module to provide functions to create customized plots.

3

4 These functions build on existing libraries, and merely serve as a shorthand for

5 plots that may be useful to evaluate groundwater models. All

6``xarray.DataArray`` and ``pandas.DataFrame`` objects have ``.plot()`` or

7``.imshow()`` methods to plot them directly.

8"""

9

10 from imod.visualize.cross_sections import cross_section, quiver, streamfunction

11 from imod.visualize.pyvista import (

12 GridAnimation3D,

13 StaticGridAnimation3D,

14 grid_3d,

15 line_3d,

16)

17 from imod.visualize.spatial import imshow_topview, plot_map, read_imod_legend

18 from imod.visualize.waterbalance import waterbalance_barchart